<?php

/**
 * This is the model class for table "Building_View".
 *
 * The followings are the available columns in table 'Building_View':
 * @property integer $RecId
 * @property integer $GroupCode
 * @property string $GroupName
 * @property integer $ParentGroupCode
 * @property string $Type
 * @property string $MarketValue
 * @property string $Description
 * @property string $GroupImage
 * @property string $add1
 * @property string $add2
 * @property string $city
 * @property string $pincode
 * @property string $phone
 * @property string $fax
 */
class BuildingView extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return BuildingView the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'Building_View';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('GroupName', 'required'),
			array('GroupCode, ParentGroupCode', 'numerical', 'integerOnly'=>true),
			array('GroupName, Type, phone, fax', 'length', 'max'=>50),
			array('MarketValue', 'length', 'max'=>19),
			array('Description, GroupImage, add1, add2, city', 'length', 'max'=>100),
			array('pincode', 'length', 'max'=>20),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('RecId, GroupCode, GroupName, ParentGroupCode, Type, MarketValue, Description, GroupImage, add1, add2, city, pincode, phone, fax', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'RecId' => 'Rec',
			'GroupCode' => 'Group Code',
			'GroupName' => 'Group Name',
			'ParentGroupCode' => 'Parent Group Code',
			'Type' => 'Type',
			'MarketValue' => 'Market Value',
			'Description' => 'Description',
			'GroupImage' => 'Group Image',
			'add1' => 'Add1',
			'add2' => 'Add2',
			'city' => 'City',
			'pincode' => 'Pincode',
			'phone' => 'Phone',
			'fax' => 'Fax',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('RecId',$this->RecId);
		$criteria->compare('GroupCode',$this->GroupCode);
		$criteria->compare('GroupName',$this->GroupName,true);
		$criteria->compare('ParentGroupCode',$this->ParentGroupCode);
		$criteria->compare('Type',$this->Type,true);
		$criteria->compare('MarketValue',$this->MarketValue,true);
		$criteria->compare('Description',$this->Description,true);
		$criteria->compare('GroupImage',$this->GroupImage,true);
		$criteria->compare('add1',$this->add1,true);
		$criteria->compare('add2',$this->add2,true);
		$criteria->compare('city',$this->city,true);
		$criteria->compare('pincode',$this->pincode,true);
		$criteria->compare('phone',$this->phone,true);
		$criteria->compare('fax',$this->fax,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}